/// <reference types="node" />
import CoronadoBridge from './bridge';
import { ILogger } from './types';
import * as http from 'http';
import { IOutboundProvider, IProviderReq } from './provider';
import BridgeError from './bridge-error';
import OutboundResponse from './outbound-response';
export interface IBridgeConfig {
    ports?: Array<number>;
    outboundProvider: IOutboundProvider;
    logger?: ILogger;
    requestTimeoutMs?: number;
    corsOptions?: object;
    jsonParsingOptions?: {
        /** When set to true, then deflated (compressed) bodies will be inflated; when false, deflated bodies are rejected. Defaults to true. */
        inflate?: boolean;
        /**
         * Controls the maximum request body size. If this is a number,
         * then the value specifies the number of bytes; if it is a string,
         * the value is passed to the bytes library for parsing. Defaults to '100kb'.
         */
        limit?: number | string;
        /**
         * The type option is used to determine what media type the middleware will parse
         * Default: application/json
         */
        type?: string | string[] | ((req: http.IncomingMessage) => any);
    };
}
export default CoronadoBridge;
export { IOutboundProvider, IProviderReq, BridgeError, OutboundResponse };
